Package: dogesr
Type: Package
Title: Work with the Doges/Dogaresse Dataset
Version: 0.5.2
Maintainer: Juan Julián Merelo-Guervós <jjmerelo@gmail.com>
Authors@R: person(given = c("Juan", "Julián"),
                  family = "Merelo-Guervós",
                  role = c("aut", "cre"),
                  email = "jjmerelo@gmail.com")
Description: Work with data on Venetian doges and dogaresse and the noble families of the Republic of Venice, and use it for social network analysis, as used in Merelo (2022) <doi:10.48550/arXiv.2209.07334>.
License: GPL-3
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5.0)
Suggests: testthat (>= 3.0.0), devtools, tidyr, networkD3, tibble
Config/testthat/edition: 3
Imports: Rdpack, dplyr, ggplot2, ggthemes, knitr, igraph, qpdf,
        rmarkdown
VignetteBuilder: knitr
RdMacros: Rdpack
RoxygenNote: 7.2.1
NeedsCompilation: no
Packaged: 2025-06-25 10:01:26 UTC; jmerelo
Author: Juan Julián Merelo-Guervós [aut, cre]
Repository: CRAN
Date/Publication: 2025-06-25 10:20:02 UTC
Built: R 4.3.3; ; 2025-07-04 04:56:18 UTC; unix
