exportPattern("^[[:alpha:]]+")
import(dplyr)
import(knitr)
import(qpdf)
import(rmarkdown)
import(ggplot2)
import(ggthemes)
importFrom(Rdpack,reprompt)
importFrom(igraph,graph_from_data_frame,V,"V<-")
